=== modified file 'NEWS'
--- NEWS	2006-10-31 22:18:23 +0000
+++ NEWS	2006-10-31 22:28:29 +0000
@@ -23,6 +23,9 @@
     * mv correctly handles paths that traverse symlinks. 
       (Aaron Bentley, #66964)
 
+    * Give nicer looking error messages when failing to connect over ssh.
+      (John Arbash Meinel, #49172)
+
     * Pushing to a remote branch does not currently update the remote working
       tree. After a remote push, ``bzr status`` and ``bzr diff`` on the remote
       machine now show that the working tree is out of date.

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-10-16 04:50:19 +0000
+++ bzrlib/errors.py	2006-10-31 21:29:02 +0000
@@ -874,6 +874,24 @@
     """Connection error: %(msg)s %(orig_error)s"""
 
 
+class SocketConnectionError(ConnectionError):
+    """%(msg)s %(host)s%(port)s%(orig_error)s"""
+
+    def __init__(self, host, port=None, msg=None, orig_error=None):
+        if msg is None:
+            msg = 'Failed to connect to'
+        if orig_error is None:
+            orig_error = ''
+        else:
+            orig_error = '; ' + str(orig_error)
+        ConnectionError.__init__(self, msg=msg, orig_error=orig_error)
+        self.host = host
+        if port is None:
+            self.port = ''
+        else:
+            self.port = ':%s' % port
+
+
 class ConnectionReset(TransportError):
     """Connection closed: %(msg)s %(orig_error)s"""
 

=== modified file 'bzrlib/tests/test_errors.py'
--- bzrlib/tests/test_errors.py	2006-10-16 04:50:19 +0000
+++ bzrlib/tests/test_errors.py	2006-10-31 21:29:02 +0000
@@ -144,3 +144,48 @@
         e = errors.TransportNotPossible('readonly', 'original error')
         self.assertEqual('Transport operation not possible:'
                          ' readonly original error', str(e))
+
+    def assertSocketConnectionError(self, expected, *args, **kwargs):
+        """Check the formatting of a SocketConnectionError exception"""
+        e = errors.SocketConnectionError(*args, **kwargs)
+        self.assertEqual(expected, str(e))
+
+    def test_socket_connection_error(self):
+        """Test the formatting of SocketConnectionError"""
+
+        # There should be a default msg about failing to connect
+        # we only require a host name.
+        self.assertSocketConnectionError(
+            'Failed to connect to ahost',
+            'ahost')
+
+        # If port is None, we don't put :None
+        self.assertSocketConnectionError(
+            'Failed to connect to ahost',
+            'ahost', port=None)
+        # But if port is supplied we include it
+        self.assertSocketConnectionError(
+            'Failed to connect to ahost:22',
+            'ahost', port=22)
+
+        # We can also supply extra information about the error
+        # with or without a port
+        self.assertSocketConnectionError(
+            'Failed to connect to ahost:22; bogus error',
+            'ahost', port=22, orig_error='bogus error')
+        self.assertSocketConnectionError(
+            'Failed to connect to ahost; bogus error',
+            'ahost', orig_error='bogus error')
+        # An exception object can be passed rather than a string
+        orig_error = ValueError('bad value')
+        self.assertSocketConnectionError(
+            'Failed to connect to ahost; %s' % (str(orig_error),),
+            host='ahost', orig_error=orig_error)
+
+        # And we can supply a custom failure message
+        self.assertSocketConnectionError(
+            'Unable to connect to ssh host ahost:444; my_error',
+            host='ahost', port=444, msg='Unable to connect to ssh host',
+            orig_error='my_error')
+
+

=== modified file 'bzrlib/tests/test_sftp_transport.py'
--- bzrlib/tests/test_sftp_transport.py	2006-09-16 06:44:47 +0000
+++ bzrlib/tests/test_sftp_transport.py	2006-09-29 21:13:35 +0000
@@ -380,7 +380,8 @@
             # paramiko, but we know about it, so we don't have to
             # fail the test
             raise TestSkipped('Known NameError bug with paramiko-1.6.1')
-        self.assertContainsRe(err, 'Connection error')
+        self.assertContainsRe(err, r'bzr: ERROR: Unable to connect to SSH host'
+                                   r' 127\.0\.0\.1:\d+; ')
 
 
 class SFTPLatencyKnob(TestCaseWithSFTPServer):

=== modified file 'bzrlib/transport/ssh.py'
--- bzrlib/transport/ssh.py	2006-09-18 09:47:56 +0000
+++ bzrlib/transport/ssh.py	2006-09-29 21:13:35 +0000
@@ -27,6 +27,7 @@
 from bzrlib.config import config_dir, ensure_config_dir_exists
 from bzrlib.errors import (ConnectionError,
                            ParamikoNotPresent,
+                           SocketConnectionError,
                            TransportError,
                            UnknownSSH,
                            )
@@ -106,7 +107,6 @@
     return _ssh_vendor
 
 
-
 def _ignore_sigint():
     # TODO: This should possibly ignore SIGHUP as well, but bzr currently
     # doesn't handle it itself.
@@ -161,6 +161,16 @@
         """
         raise NotImplementedError(self.connect_ssh)
         
+    def _raise_connection_error(self, host, port=None, orig_error=None,
+                                msg='Unable to connect to SSH host'):
+        """Raise a SocketConnectionError with properly formatted host.
+
+        This just unifies all the locations that try to raise ConnectionError,
+        so that they format things properly.
+        """
+        raise SocketConnectionError(host=host, port=port, msg=msg,
+                                    orig_error=orig_error)
+
 
 class LoopbackVendor(SSHVendor):
     """SSH "vendor" that connects over a plain TCP socket, not SSH."""
@@ -170,8 +180,7 @@
         try:
             sock.connect((host, port))
         except socket.error, e:
-            raise ConnectionError('Unable to connect to SSH host %s:%s: %s'
-                                  % (host, port, e))
+            self._raise_connection_error(host, port=port, orig_error=e)
         return SFTPClient(LoopbackSFTP(sock))
 
 register_ssh_vendor('loopback', LoopbackVendor())
@@ -201,8 +210,7 @@
             t.set_log_channel('bzr.paramiko')
             t.start_client()
         except (paramiko.SSHException, socket.error), e:
-            raise ConnectionError('Unable to reach SSH host %s:%s: %s' 
-                                  % (host, port, e))
+            self._raise_connection_error(host, port=port, orig_error=e)
             
         server_key = t.get_remote_server_key()
         server_key_hex = paramiko.util.hexify(server_key.get_fingerprint())
@@ -236,8 +244,8 @@
         try:
             return t.open_sftp_client()
         except paramiko.SSHException, e:
-            raise ConnectionError('Unable to start sftp client %s:%d' %
-                                  (host, port), e)
+            self._raise_connection_error(host, port=port, orig_error=e,
+                                         msg='Unable to start sftp client')
 
     def connect_ssh(self, username, password, host, port, command):
         t = self._connect(username, password, host, port)
@@ -247,8 +255,8 @@
             channel.exec_command(cmdline)
             return _ParamikoSSHConnection(channel)
         except paramiko.SSHException, e:
-            raise ConnectionError('Unable to invoke remote bzr %s:%d' %
-                                  (host, port), e)
+            self._raise_connection_error(host, port=port, orig_error=e,
+                                         msg='Unable to invoke remote bzr')
 
 register_ssh_vendor('paramiko', ParamikoVendor())
 
@@ -270,16 +278,14 @@
             sock = self._connect(argv)
             return SFTPClient(sock)
         except (EOFError, paramiko.SSHException), e:
-            raise ConnectionError('Unable to connect to SSH host %s:%s: %s'
-                                  % (host, port, e))
+            self._raise_connection_error(host, port=port, orig_error=e)
         except (OSError, IOError), e:
             # If the machine is fast enough, ssh can actually exit
             # before we try and send it the sftp request, which
             # raises a Broken Pipe
             if e.errno not in (errno.EPIPE,):
                 raise
-            raise ConnectionError('Unable to connect to SSH host %s:%s: %s'
-                                  % (host, port, e))
+            self._raise_connection_error(host, port=port, orig_error=e)
 
     def connect_ssh(self, username, password, host, port, command):
         try:
@@ -287,16 +293,14 @@
                                                   command=command)
             return self._connect(argv)
         except (EOFError), e:
-            raise ConnectionError('Unable to connect to SSH host %s:%s: %s'
-                                  % (host, port, e))
+            self._raise_connection_error(host, port=port, orig_error=e)
         except (OSError, IOError), e:
             # If the machine is fast enough, ssh can actually exit
             # before we try and send it the sftp request, which
             # raises a Broken Pipe
             if e.errno not in (errno.EPIPE,):
                 raise
-            raise ConnectionError('Unable to connect to SSH host %s:%s: %s'
-                                  % (host, port, e))
+            self._raise_connection_error(host, port=port, orig_error=e)
 
     def _get_vendor_specific_argv(self, username, host, port, subsystem=None,
                                   command=None):

